Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(335)

Unified Diff: content/browser/vr/vr_device_manager_unittest.cc

Issue 1832813002: Add mojom module suffix in .mojom files in content. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address Tom's comment Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/vr/vr_device_manager.cc ('k') | content/browser/wake_lock/wake_lock_browsertest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/vr/vr_device_manager_unittest.cc
diff --git a/content/browser/vr/vr_device_manager_unittest.cc b/content/browser/vr/vr_device_manager_unittest.cc
index 346760fac8f18374b6b8df651a4c82efb86d9ebd..86f35ae1d65f3acb976a069cba1bc0f4df21dc49 100644
--- a/content/browser/vr/vr_device_manager_unittest.cc
+++ b/content/browser/vr/vr_device_manager_unittest.cc
@@ -48,15 +48,15 @@ TEST_F(VRDeviceManagerTest, InitializationTest) {
// Calling GetDevices should initialize the service if it hasn't been
// initialized yet or the providesr have been released.
// The VRService should initialize each of it's providers upon it's own
// initialization.
- mojo::Array<VRDeviceInfoPtr> webvr_devices;
+ mojo::Array<mojom::VRDeviceInfoPtr> webvr_devices;
webvr_devices = device_manager_->GetVRDevices();
EXPECT_TRUE(provider_->IsInitialized());
}
TEST_F(VRDeviceManagerTest, GetDevicesBasicTest) {
- mojo::Array<VRDeviceInfoPtr> webvr_devices;
+ mojo::Array<mojom::VRDeviceInfoPtr> webvr_devices;
webvr_devices = device_manager_->GetVRDevices();
// Calling GetVRDevices should initialize the providers.
EXPECT_TRUE(provider_->IsInitialized());
@@ -48,15 +48,15 @@ TEST_F(VRDeviceManagerTest, InitializationTest) {
// Calling GetDevices should initialize the service if it hasn't been
// initialized yet or the providesr have been released.
- // The VRService should initialize each of it's providers upon it's own
+ // The mojom::VRService should initialize each of it's providers upon it's own
// initialization.
« no previous file with comments | « content/browser/vr/vr_device_manager.cc ('k') | content/browser/wake_lock/wake_lock_browsertest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698